@@ -226,7 +226,7 @@ class mysql:
    def mysqlQuerySilent(self,query):
       df='err:'
       try:
-         sqlEngine       = create_engine('mysql+pymysql://'+self.userx+':'+self.passx+'@'+self.servidorx)
+         sqlEngine       = create_engine('mysql+pymysql://'+self.userx+':'+self.passx+'@'+self.servidorx+':'+self.port)
          dbConnection    = sqlEngine.connect()
          frame           = pd.read_sql(query, dbConnection);
          dbConnection.close()
